/*
 Copyright (C) 2021 Momi-g

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

/*SH_doc
title=ped section=1
@name	ped
@_brief	sed-style editer using peg
@synopsis
	ped [-e str|-f rulefile] [-n|N] [-r|R] [-t|T] [-hHgVodEL] file/stdin
@tl;dr
	@(code)@
	~$ echo "12a"|ped -re 'ID<-[a-z]+ {_1="Z"}'
		>>> 12Z
	@()
@_desc
	see ~$ ped -h or -H
@copyright
	Copyright (C) 2021 Momi-g --
	License GPLv3+ <https://gnu.org/licenses/gpl.html>.
//SH_docE*/
#ifndef ped_main_5906e77bc764
#define ped_main_5906e77bc764
//no header. runner src only

#endif /* inc grd */
